#
# spec file for package gspell
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib lib%{name}-1-2
Name:           gspell
Version:        1.12.2
Release:        1.1
Summary:        A spell checker library for GTK+ applications
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://wiki.gnome.org/Projects/gspell
Source0:        https://download.gnome.org/sources/gspell/1.12/%{name}-%{version}.tar.xz

BuildRequires:  gtk-doc >= 1.25
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(enchant-2) >= 2.1.3
BuildRequires:  pkgconfig(glib-2.0) >= 2.44
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.42.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(iso-codes) >= 0.35
%ifarch aarch64 %{ix86} x86_64 ppc ppc64 ppc64le s390x armv7l armv7hl armv6l armv6hl
BuildRequires:  pkgconfig(valgrind)
%endif
BuildRequires:  pkgconfig(vapigen)

%description
gspell provides a flexible API to implement the spell checking in a GTK+
application.

%package -n %{shlib}
Summary:        Spell checker library for GTK+
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n %{shlib}
gspell provides a flexible API to implement the spell checking in a GTK+
application.

This package provides the shared libraries for gspell.

%package -n typelib-1_0-Gspell-1
Summary:        Introspection bindings for the GTK+ spell checker library
# typelib name was wrong until version 1.7.1; obsolete to ease upgrade path
Group:          System/Libraries
Obsoletes:      typelib-1_0-Gspell-1_0 < 1.7.1

%description -n typelib-1_0-Gspell-1
gspell provides a flexible API to implement the spell checking in a GTK+
application.

This package provides the GObject Introspection bindings for gspell.

%package devel
Summary:        Development files for the GTK+ spell checker library
Group:          Development/Libraries/GNOME
Requires:       %{shlib} = %{version}
Requires:       typelib-1_0-Gspell-1 = %{version}

%description devel
gspell provides a flexible API to implement the spell checking in a GTK+
application.

This package provides the files necessary for developing software using
gspell.

%lang_package

%prep
%autosetup -p1

%build
%configure \
	--disable-static \
	--enable-gtk-doc
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}-1 %{?no_lang_C}

%ldconfig_scriptlets -n %{shlib}

%files
%license COPYING
%doc AUTHORS ChangeLog README NEWS
%{_bindir}/gspell-app1

%files -n %{shlib}
%{_libdir}/lib%{name}-1.so.*

%files -n typelib-1_0-Gspell-1
%{_libdir}/girepository-1.0/Gspell-1.typelib

%files devel
%doc %{_datadir}/gtk-doc/html/gspell-1.0/
%{_includedir}/gspell-1/
%{_libdir}/lib%{name}-1.so
%{_libdir}/pkgconfig/gspell-1.pc
%{_datadir}/gir-1.0/*.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gspell-1.*

%files lang -f %{name}-1.lang

%changelog
* Thu Aug 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.12.2:
  + Small code maintenance: don't use g_slice_*().
* Mon May  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.12.1:
  + Build: remove gtk-mac-integration dependency.
  + Documentation improvements.
  + Updated translations.
- Use autosetup and ldconfig_scriptlets macros.
* Tue Sep 27 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.12.0:
  + Use G_MODULE_EXPORT instead of the custom _GSPELL_EXTERN macro.
  + Small maintenance tasks, some minor simplifications.
  + Updated translations.
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- Conditionalize valgrind dependency, not available on all
  architectures.
* Mon Jul  4 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 1.11.1:
  + Build: minor improvements, small change to how enum-types are
    built.
  + A few documentation improvements.
* Tue Apr 19 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 1.10.0:
  + Build from git: some updates, take newer version of autoconf-archive.
  + Build: distribute more files in tarballs.
  + Documentation improvements.
  + Translation updates.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 1.8.4:
  + Updated translations.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sat Jan 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.3:
  + Small maintenance stuff.
  + Updated translations.
* Fri Sep  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.2:
  + Build from Git: allow building with gettext ≥ 0.20.
  + Updated translations.
* Sun Jun 17 2018 bjorn.lie@gmail.com
- Update to version 1.8.1:
  + Fix new compilation warning (-Wcast-function-type).
  + Updated translations.
* Tue Mar 13 2018 jengelh@inai.de
- Update summaries.
* Sun Mar 11 2018 dimstar@opensuse.org
- Update to version 1.8.0:
  + Build system: don't declare functions in AC_TRY_COMPILE.
  + Updated translations.
- Bump shlib define lib%%{name}-1-2, effectivley changing the name
  of the shared library package: following upstream sover bump.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Dec  9 2017 luc14n0@linuxmail.org
- Update to version 1.7.1:
  + Use Enchant 2.
  + Improve documentation.
  + Updated translations.
- Switch pkgconfig(enchant) BuildRequires by enchant-2 module
  following ustream change.
- Adopt the use of %%make_build macro instead of raw make command,
  following best practices.
- Fix spelling in summaries.
- Rename typelib-1_0-Gspell-1_0 to typelib-1_0-Gspell-1,
  following the tyeplib naming convention (old name was wrongly
  chosen). For this reason, obsolete the old, wrong name.
* Tue Oct 31 2017 luc14n0@linuxmail.org
- Update to version 1.6.1:
  + Updated translations.
- Drop pkgconfig BuildRequires: devel packages implicit dependency.
* Sun Sep 10 2017 dimstar@opensuse.org
- Update to version 1.6.0:
  + Updated translations.
* Sun Aug 20 2017 zaitor@opensuse.org
- Update to version 1.5.4:
  + Make the code that navigates through PangoLogAttr's more
    robust, for both GspellEntry and GspellTextView.
  + Updated translations.
* Sat Aug 19 2017 zaitor@opensuse.org
- Update to version 1.5.3:
  + Add gspell_checker_get_enchant_dict(), the use of Enchant is
    now part of the API.
  + Rename program gspell-app to gspell-app1.
  + Various other small improvements.
  + Updated translations.
* Sat Aug 19 2017 zaitor@opensuse.org
- Update to version 1.5.2:
  + Implement small gspell-app, a convenient way to quickly
    spell-check something.
  + Document the support of the no-spell-check GtkTextTag.
  + Various other small improvements.
  + Updated translations.
* Sat Aug 19 2017 zaitor@opensuse.org
- Update to version 1.5.1:
  + Change underline type to PANGO_UNDERLINE_SINGLE, to remove the
    workaround for the GtkTextView bug where wavy underlines are
    not properly removed (bgo#763741).
  + Up to 20x faster implementation for the GtkTextView inline
    spell-checker, to fix a responsiveness problem when editing
    long lines.
  + Rework symbol visibility handling, by using the -export-dynamic
    LDFLAG and -fvisibility=hidden CFLAG, instead of the
  - export-symbols-regex LDFLAG.
  + Add note for packagers in the README file: aspell doesn't work
    well with gspell, hunspell is preferred.
  + Various other small improvements.
  + Updated translations.
* Sat Aug 19 2017 zaitor@opensuse.org
- Update to version 1.4.2:
  + GspellEntry: make the code that navigates through
    PangoLogAttr's more robust.
  + Updated translations.
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 1.4.1:
  + GspellEntry: do not emit the GtkEditable::changed signal.
  + Replace some g_asserts by g_returns to avoid crashes
    (bgo#778883).
  + Updated translations.
* Sun Mar 19 2017 zaitor@opensuse.org
- Update to version 1.4.0:
  + Other small improvements.
  + Updated translations.
* Sun Feb 26 2017 dimstar@opensuse.org
- Update to version 1.3.3:
  + Add more assertions for bgo#778883.
  + Fix minor issues found by Coverity.
  + Updated translations.
* Mon Jan 16 2017 dimstar@opensuse.org
- Update to version 1.3.2:
  + GspellEntry: do not check the word currently typed.
  + GspellEntry: better word boundaries, take into account
    apostrophes and dashes.
  + GspellEntry: disable inline spell checking if the GtkEntry is
    in password mode.
  + Various other improvements.
* Fri Dec 16 2016 dimstar@opensuse.org
- Update to version 1.3.1:
  + Add inline spell-checking support for GtkEntry (the bases are
    there).
  + GtkTextView support: fix populate-popup signal param type.
  + Updated translations.
* Fri Dec 16 2016 zaitor@opensuse.org
- Update to version 1.2.2:
  + GtkTextView support: fix populate-popup signal param type.
* Sun Nov  6 2016 zaitor@opensuse.org
- Update to version 1.2.1:
  + Updated translations.
* Sun Sep 18 2016 zaitor@opensuse.org
- Update to version 1.2.0:
  + Updated translations.
* Sun Aug 14 2016 zaitor@opensuse.org
- Update to version 1.1.3:
  + Add the gspell_text_view_basic_setup() convenience function to
    enable inline spell-checking in a GtkTextView in 2 lines.
  + Support words separated by dashes (compounds).
  + Use the AX_VALGRIND_CHECK Autotools macro.
  + Updated translations.
- Add pkgconfig(valgrind) BuildRequires: Build the new valgrind
  support.
- Pass --enable-gtk-doc to configure: Actually build the
  documentation, we already have the needed BuildRequires in place.
* Sun Jul 17 2016 zaitor@opensuse.org
- Update to version 1.1.2:
  + Inline checker: fix constant redrawing of the GtkTextView when
    the current word is not checked.
  + Generate enum types.
  + Updated translations.
* Wed Jul 13 2016 zaitor@opensuse.org
- Update to version 1.1.1:
  + New API: inline checker: add an option to select the language
    from the context menu (right-click menu).
  + Fix gtk-doc build issue.
  + Update GtkTextRegion -> GtkSourceRegion (utility class copied
    from the GtkSourceView library).
  + Updated translations.
* Sun Jul 10 2016 zaitor@opensuse.org
- Update to version 1.0.3:
  + Inline checker: fix constant redrawing of the GtkTextView when
    the current word is not checked (bgo#768306).
  + Updated translations.
* Sat Jun 11 2016 zaitor@opensuse.org
- Update to version 1.0.2:
  + Fix gtk-doc build issue.
  + Updated translations.
* Sun Apr 10 2016 zaitor@opensuse.org
- Update to version 1.0.1:
  + Fix build on win32.
  + Updated translations.
* Sun Mar 20 2016 zaitor@opensuse.org
- Update to version 1.0.0:
  + The API is now stable. Future 1.x stable versions will be
    backward compatible with the 1.0 version.
  + Updated translations.
- Bump soname following upstream changes.
* Mon Mar 14 2016 zaitor@opensuse.org
- Update to version 0.2.6:
  + Fix builddir != srcdir issue (it occurred only in Git, not in
    tarballs normally).
  + Install tests in <...>/installed-tests/gspell-1/ instead of
    gspell/, to follow the parallel installability convention.
- Changes from version 0.2.5:
  + Inline checker: improve current word handling.
  + Support words with apostrophes, like "doesn't".
  + Write more unit tests.
  + Improvements to the build system (use a GSPELL_API_VERSION
    variable).
  + Add missing getter functions.
  + Installed tests support.
  + API changes:
  - Have a GspellTextBuffer class.
  - Rename GspellInlineCheckerTextView -> GspellTextView.
  - The GspellNavigator interface now requires GInitiallyUnowned
    instead of GObject.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 0.2.4:
  + Fix compilation on Mac OS X.
  + Write the first unit tests.
  + Inline checker for GtkTextView:
  - Fix bug with neighbor words.
  - Fix underline drawing issue.
  - Don't check current word while typing.
  + Other code improvements.
  + Updated translations.
* Wed Jan 20 2016 dimstar@opensuse.org
- Update to verstion 0.2.3:
  + GspellLanguage: code improvements, write API documentation and
    add get_default() function.
  + Add gspell_text_buffer_set/get_spell_checker() functions.
  + GspellNavigatorGtv renamed to GspellNavigatorText.
  + Remove GspellNavigatorText:spell-checker property,
  + GspellInlineCheckerGtv replaced by the higher-level class
    GspellInlineCheckerText.
  + Language choosers: accept NULL language to pick the default
    language.
  + Add the GspellLanguageChooser:language-code property, for a
    GSettings key binding.
  + GspellChecker: accept a NULL language in case no dictionaries
    are available.
  + Other code and documentation improvements.
  + Updated translations.
* Tue Dec 15 2015 badshah400@gmail.com
- Update to version 0.2.2:
  + Relicense gspell from GPLv2+ to LGPLv2.1+.
  + Get rid of the libxml2 and GtkSourceView dependencies.
  + Replace the GspellLanguage implementation by the GtkHtml one
    to get rid of the libxml2 dependency and have a code licensed
    under the LGPL.
  + Code improvements to GspellInlineCheckerGtv.
  + API changes:
  - Rename gspell_language_from_key() to
    gspell_language_lookup().
  - Rename gspell_language_to_key() to
    gspell_language_get_code().
  - Rename gspell_language_to_string() to
    gspell_language_get_name().
  - Rename gspell_checker_get_available_languages() to
    gspell_language_get_available() and return a GList instead
    of a GSList.
  - Rename GspellChecker signals:
    + ::add-word-to-personal -> ::word-added-to-personal.
    + ::add-word-to-session -> ::word-added-to-session.
    + ::clear-session -> ::session-cleared.
- Drop pkgconfig(gtksourceview-3.0) and pkgconfig(libxml-2.0)
  BuildRequires, following upstream changes.
- Own the %%{_datadir}/vala/vapi directory, required due to
  dropping of gtksourceview from BuildRequires which owned it
  previously.
* Mon Nov 23 2015 zaitor@opensuse.org
- Update to version 0.2.1:
  + Allow only <gspell/gspell.h> to be #included directly.
  + Make GspellCheckerDialog derivable.
  + Make GspellLanguageChooserDialog derivable.
  + Add a GtkDialogFlags parameter to
    gspell_language_chooser_dialog_new().
  + Add string length parameters to GspellChecker functions.
* Thu Nov 19 2015 zaitor@opensuse.org
- Update to version 0.1.2:
  + gspell has now a bugzilla product on gnome.org.
  + GTK-Doc: rename DOC_MODULE to gspell-1.0, to make the API
    reference available online at:
    https://developer.gnome.org/references
* Sun Nov  8 2015 badshah400@gmail.com
- Initial package.
